# foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

A document without any content.

Both of the following should produce warnings. Also, the data-algorithm attributes should be correctly set.

## 1. String creation

Let var be a string.

## 2. Make a non-string.

Let var be anything other than a string. Really. Anything.